@@ -44,7 +44,7 @@ class NuisanceParameterPull(object):
             },
             'parameter'  : {
                 'abbr'        : 'p',
-                'description' : 'Parameter to rank', 
+                'description' : 'Parameter to run pulls on', 
                 'required'    : True,
                 'type'        : str,
             },   
@@ -53,7 +53,7 @@ class NuisanceParameterPull(object):
                 'description' : 'POIs to measure',
                 'required'    : False,
                 'type'        : str,
-                'default'     : "mu"
+                'default'     : ""
             },
             'profile': {
                 'abbr'        : 'r',
@@ -266,8 +266,8 @@ class NuisanceParameterPull(object):
         return poi_values, elapsed_time
         
     def run_pulls(self, input_file='workspace.root', workspace='combWS', model_config='ModelConfig',
-                 data='combData', poi='mu', snapshot='nominalNuis', outdir='output', profile="",
-                 fix="", minimizer_type='Minuit2', minimizer_algo='Migrad', num_cpu=1, binned=1,
+                 data='combData', poi='', snapshot='nominalNuis', outdir='output', profile="",
+                 fix='', minimizer_type='Minuit2', minimizer_algo='Migrad', num_cpu=1, binned=1,
                  precision=0.001, eps=1.0, log_level='INFO', eigen=0, strategy=0, fix_cache=1, fix_multi=1,
                  offset=1, optimize=2, parameter="", max_calls=-1, max_iters=-1, **kwargs):
         
@@ -367,38 +367,41 @@ class NuisanceParameterPull(object):
         prefit_uncertainty_time = time.time() - buffer_time
         print('INFO: Time to find prefit variation: {}s'.format(prefit_uncertainty_time))
         
-        new_minimizer_options = {
-            'nll_commands': nll_commands,
-            'reuse_nll'   : 1,
-            **minimize_options
-        }
-        # fix theta at the MLE value +/- postfit uncertainty and minimize again to estimate the change in the POI
-        print('INFO: Evaluating effect of moving {} up by {} + {}'.format(nuip_name, nuip_hat, nuip_errup))
-        pois_up, postfit_up_impact_time = self.evaluate_impact(nuip, nuip_hat + abs(nuip_errup), rank_pois,
-                                                               new_minimizer_options,  'tmp_snapshot')
-        print('INFO: Time to find postfit up impact: {}s'.format(postfit_up_impact_time))
-        
-        print('INFO: Evaluating effect of moving {} down by {} - {}'.format(nuip_name, nuip_hat, nuip_errup))
-        pois_down, postfit_down_impact_time = self.evaluate_impact(nuip, nuip_hat - abs(nuip_errdown), rank_pois,
+        if rank_pois:
+            new_minimizer_options = {
+                'nll_commands': nll_commands,
+                'reuse_nll'   : 1,
+                **minimize_options
+            }
+            # fix theta at the MLE value +/- postfit uncertainty and minimize again to estimate the change in the POI
+            print('INFO: Evaluating effect of moving {} up by {} + {}'.format(nuip_name, nuip_hat, nuip_errup))
+            pois_up, postfit_up_impact_time = self.evaluate_impact(nuip, nuip_hat + abs(nuip_errup), rank_pois,
                                                                    new_minimizer_options,  'tmp_snapshot')
-        print('INFO: Time to find postfit down impact: {}s'.format(postfit_down_impact_time))
-        
-        # fix theta at the MLE value +/- prefit uncertainty and minimize again to estimate the change in the POI
-        
-        if constraint_type:
-            print('Evaluating effect of moving {} up by {} + {}'.format(nuip_name, nuip_hat, prefit_variation))
-            pois_nom_up, prefit_up_impact_time = self.evaluate_impact(nuip, nuip_hat + prefit_variation, rank_pois,
-                                                                      new_minimizer_options,  'tmp_snapshot')
-            print('INFO: Time to find prefit up impact: {}s'.format(prefit_up_impact_time))      
+            print('INFO: Time to find postfit up impact: {}s'.format(postfit_up_impact_time))
             
-            print('Evaluating effect of moving {} down by {} - {}'.format(nuip_name, nuip_hat, prefit_variation))
-            pois_nom_down, prefit_down_impact_time = self.evaluate_impact(nuip, nuip_hat - prefit_variation, rank_pois,
+            print('INFO: Evaluating effect of moving {} down by {} - {}'.format(nuip_name, nuip_hat, nuip_errup))
+            pois_down, postfit_down_impact_time = self.evaluate_impact(nuip, nuip_hat - abs(nuip_errdown), rank_pois,
+                                                                       new_minimizer_options,  'tmp_snapshot')
+            print('INFO: Time to find postfit down impact: {}s'.format(postfit_down_impact_time))
+            
+            # fix theta at the MLE value +/- prefit uncertainty and minimize again to estimate the change in the POI
+            
+            if constraint_type:
+                print('Evaluating effect of moving {} up by {} + {}'.format(nuip_name, nuip_hat, prefit_variation))
+                pois_nom_up, prefit_up_impact_time = self.evaluate_impact(nuip, nuip_hat + prefit_variation, rank_pois,
                                                                           new_minimizer_options,  'tmp_snapshot')
-            print('INFO: Time to find prefit down impact: {}s'.format(prefit_up_impact_time))
+                print('INFO: Time to find prefit up impact: {}s'.format(prefit_up_impact_time))      
+                
+                print('Evaluating effect of moving {} down by {} - {}'.format(nuip_name, nuip_hat, prefit_variation))
+                pois_nom_down, prefit_down_impact_time = self.evaluate_impact(nuip, nuip_hat - prefit_variation, rank_pois,
+                                                                              new_minimizer_options,  'tmp_snapshot')
+                print('INFO: Time to find prefit down impact: {}s'.format(prefit_up_impact_time))
+            else:
+                print('WARNING: Prefit impact not estimated, instead postfit impact is cloned')
+                pois_nom_up = [i for i in pois_up]
+                pois_nom_down = [i for i in pois_down]
         else:
-            print('WARNING: Prefit impact not estimated, instead postfit impact is cloned')
-            pois_nom_up = [i for i in pois_up]
-            pois_nom_down = [i for i in pois_down]
+        	pois_up, pois_down, pois_nom_up, pois_nom_down = [], [], [], []
         
         end_time = time.time()
         print('\nINFO: Time to perform all fits: {}s'.format(end_time-start_time))
